@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -27,10 +27,10 @@
 using namespace std;
 using namespace graph_tool;
 
-void do_get_closeness(GraphInterface& gi, boost::any weight,
-                      boost::any closeness, bool harmonic, bool norm)
+void do_get_closeness(GraphInterface& gi, std::any weight,
+                      std::any closeness, bool harmonic, bool norm)
 {
-    if (weight.empty())
+    if (!weight.has_value())
     {
         run_action<>()
             (gi,
@@ -41,7 +41,7 @@ void do_get_closeness(GraphInterface& gi, boost::any weight,
                       gi.get_vertex_index(), no_weightS(),
                       std::forward<decltype(a2)>(a2), harmonic, norm);
              },
-             writable_vertex_scalar_properties())(closeness);
+             writable_vertex_scalar_properties)(closeness);
     }
     else
     {
@@ -54,8 +54,8 @@ void do_get_closeness(GraphInterface& gi, boost::any weight,
                       gi.get_vertex_index(), std::forward<decltype(a2)>(a2),
                       std::forward<decltype(a3)>(a3), harmonic, norm);
              },
-             edge_scalar_properties(),
-             writable_vertex_scalar_properties())(weight, closeness);
+             edge_scalar_properties,
+             writable_vertex_scalar_properties)(weight, closeness);
     }
 }
 
