@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -27,30 +27,30 @@ using namespace std;
 using namespace boost;
 using namespace graph_tool;
 
-void katz(GraphInterface& g, boost::any w, boost::any c, boost::any beta,
+void katz(GraphInterface& g, std::any w, std::any c, std::any beta,
           long double alpha, double epsilon, size_t max_iter)
 {
-    if (!w.empty() && !belongs<writable_edge_scalar_properties>()(w))
+    if (w.has_value() && !belongs(writable_edge_scalar_properties, w))
         throw ValueException("edge property must be writable");
-    if (!belongs<vertex_floating_properties>()(c))
+    if (!belongs(vertex_floating_properties, c))
         throw ValueException("centrality vertex property must be of floating point"
                              " value type");
-    if (!beta.empty() && !belongs<vertex_floating_properties>()(beta))
+    if (beta.has_value() && !belongs(vertex_floating_properties, beta))
         throw ValueException("personalization vertex property must be of floating point"
                              " value type");
 
     typedef UnityPropertyMap<int,GraphInterface::edge_t> weight_map_t;
-    typedef boost::mpl::push_back<writable_edge_scalar_properties, weight_map_t>::type
-        weight_props_t;
+    auto weight_props = hana::append(writable_edge_scalar_properties,
+                                    hana::type<weight_map_t>());
 
-    if(w.empty())
+    if (!w.has_value())
         w = weight_map_t();
 
     typedef UnityPropertyMap<int,GraphInterface::vertex_t> beta_map_t;
-    typedef boost::mpl::push_back<vertex_floating_properties, beta_map_t>::type
-        beta_props_t;
+    auto beta_props = hana::append(vertex_floating_properties,
+                                     hana::type<beta_map_t>());
 
-    if(beta.empty())
+    if (!beta.has_value())
         beta = beta_map_t();
 
     run_action<>()
@@ -63,8 +63,8 @@ void katz(GraphInterface& g, boost::any w, boost::any c, boost::any beta,
                   std::forward<decltype(a3)>(a3),
                   std::forward<decltype(a4)>(a4), alpha, epsilon, max_iter);
          },
-         weight_props_t(), vertex_floating_properties(),
-         beta_props_t())(w, c, beta);
+         weight_props, vertex_floating_properties,
+         beta_props)(w, c, beta);
 }
 
 #define __MOD__ centrality
