@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -22,23 +22,23 @@ using namespace std;
 using namespace boost;
 using namespace graph_tool;
 
-void generate_sbm(GraphInterface& gi, boost::any ab, boost::python::object ors,
+void generate_sbm(GraphInterface& gi, std::any ab, boost::python::object ors,
                   boost::python::object oss, boost::python::object oprobs,
-                  boost::any ain_deg, boost::any aout_deg, bool micro_ers,
+                  std::any ain_deg, std::any aout_deg, bool micro_ers,
                   bool micro_degs, rng_t& rng)
 {
     auto rs = get_array<int64_t, 1>(ors);
     auto ss = get_array<int64_t, 1>(oss);
 
-    typedef vprop_map_t<int32_t>::type bmap_t;
-    auto b = any_cast<bmap_t>(ab).get_unchecked();
+    typedef vprop_map_t<int32_t> bmap_t;
+    auto b = std::any_cast<bmap_t>(ab).get_unchecked();
 
     if (micro_degs)
     {
         auto probs = get_array<uint64_t, 1>(oprobs);
-        typedef vprop_map_t<int64_t>::type dmap_t;
-        auto in_deg = any_cast<dmap_t>(ain_deg).get_unchecked();
-        auto out_deg = any_cast<dmap_t>(aout_deg).get_unchecked();
+        typedef vprop_map_t<int64_t> dmap_t;
+        auto in_deg = std::any_cast<dmap_t>(ain_deg).get_unchecked();
+        auto out_deg = std::any_cast<dmap_t>(aout_deg).get_unchecked();
         run_action<>()
             (gi, [&](auto& g) { gen_sbm<true>(g, b, rs, ss, probs, in_deg,
                                               out_deg, true, rng); })();
@@ -46,9 +46,9 @@ void generate_sbm(GraphInterface& gi, boost::any ab, boost::python::object ors,
     else
     {
         auto probs = get_array<double, 1>(oprobs);
-        typedef vprop_map_t<double>::type dmap_t;
-        auto in_deg = any_cast<dmap_t>(ain_deg).get_unchecked();
-        auto out_deg = any_cast<dmap_t>(aout_deg).get_unchecked();
+        typedef vprop_map_t<double> dmap_t;
+        auto in_deg = std::any_cast<dmap_t>(ain_deg).get_unchecked();
+        auto out_deg = std::any_cast<dmap_t>(aout_deg).get_unchecked();
         run_action<>()
             (gi, [&](auto& g) { gen_sbm<false>(g, b, rs, ss, probs, in_deg,
                                                out_deg, micro_ers, rng); })();
