@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -23,21 +23,21 @@ using namespace boost;
 using namespace graph_tool;
 
 void generate_triadic_closure(GraphInterface& gi,
-                              boost::any acurr,
-                              boost::any aego,
-                              boost::any aEs,
+                              std::any acurr,
+                              std::any aego,
+                              std::any aEs,
                               bool probs, rng_t& rng)
 {
-    typedef eprop_map_t<uint8_t>::type emap_t;
-    auto curr = any_cast<emap_t>(acurr).get_unchecked();
+    typedef eprop_map_t<uint8_t> emap_t;
+    auto curr = std::any_cast<emap_t>(acurr).get_unchecked();
 
-    typedef eprop_map_t<int64_t>::type eemap_t;
-    auto ego = any_cast<eemap_t>(aego);
+    typedef eprop_map_t<int64_t> eemap_t;
+    auto ego = std::any_cast<eemap_t>(aego);
 
     run_action<>()(gi,
                    [&](auto& g, auto Es) { gen_triadic_closure(g, curr, ego, Es,
                                                                probs, rng); },
-                   vertex_scalar_properties())(aEs);
+                   vertex_scalar_properties)(aEs);
 }
 
 using namespace boost::python;
