@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -36,27 +36,19 @@ GraphInterface::GraphInterface()
      _directed(true),
      _graph_index(0),
      _vertex_filter_map(_vertex_index),
-     _vertex_filter_invert(false),
      _vertex_filter_active(false),
      _edge_filter_map(_edge_index),
-     _edge_filter_invert(false),
      _edge_filter_active(false)
 {
 }
 
-// the destructor
-GraphInterface::~GraphInterface()
-{
-}
-
 // this will get the number of vertices, either the "soft" O(1) way, or the hard
 // O(V) way, which is necessary if the graph is filtered
 size_t GraphInterface::get_num_vertices(bool filtered)
 {
     size_t n = 0;
     if (filtered && is_vertex_filter_active())
-        run_action<>()(*this, lambda::var(n) =
-                       lambda::bind<size_t>(HardNumVertices(),lambda::_1))();
+        run_action<>()(*this, [&](auto& g){ n = hard_num_vertices(g); })();
     else
         n = num_vertices(*_mg);
     return n;
@@ -70,8 +62,7 @@ size_t GraphInterface::get_num_edges(bool filtered)
     using namespace boost::lambda;
     size_t n = 0;
     if (filtered && (is_edge_filter_active() || is_vertex_filter_active()))
-        run_action<>()(*this, lambda::var(n) =
-                       lambda::bind<size_t>(HardNumEdges(),lambda::_1))();
+        run_action<>()(*this, [&](auto& g){ n = hard_num_edges(g); })();
     else
         n = num_edges(*_mg);
     return n;
