@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -43,7 +43,7 @@ struct LibInfo
     string GetVersion()   const {return VERSION " (commit " GIT_COMMIT
                                         ", " GIT_COMMIT_DATE ")";}
     string GetLicense()   const {return "GPL version 3 or above";}
-    string GetCXXFLAGS()  const {return CPPFLAGS " " CXXFLAGS " " LDFLAGS;}
+    string GetCXXFLAGS()  const {return CPPFLAGS " " MOD_CXXFLAGS " " CXXFLAGS " " LDFLAGS;}
     string GetInstallPrefix() const {return INSTALL_PREFIX;}
     string GetPythonDir() const {return PYTHON_DIR;}
     string GetGCCVersion() const
@@ -78,7 +78,7 @@ struct vector_from_list
         python::object o(x);
         vector<ValueType> value;
         auto init_iter =
-            [&]
+            [&]()
             {
                 python::stl_input_iterator<ValueType> iter(o), end;
                 for (; iter != end; ++iter)
@@ -150,19 +150,25 @@ void set_vector_state(std::vector<T>& v, python::object state)
     v.insert(v.end(), a.begin(), a.end());
 }
 
+namespace std
+{
+bool operator==(const std::any&, const std::any&)
+{
+    throw ValueException("std::any comparison not implemented.");
+}
+}
+
+template <bool comparable=true, bool hashable=true>
 struct export_vector_types
 {
     template <class ValueType>
     void operator()(ValueType, std::string type_name = "") const
     {
         if (type_name.empty())
-            type_name = get_type_name<>()(typeid(ValueType));
+            type_name = get_type_name<ValueType>();
         std::replace(type_name.begin(), type_name.end(), ' ', '_');
         string name = "Vector_" + type_name;
         class_<vector<ValueType> > vc(name.c_str());
-        std::function<size_t(const vector<ValueType>&)> hasher =
-            [] (const vector<ValueType>& v) -> size_t
-            { return std::hash<vector<ValueType>>()(v); };
         std::function<void(vector<ValueType>&, size_t size)> resize =
             [] (vector<ValueType>& v, size_t n) { v.resize(n); };
         std::function<void(vector<ValueType>&, size_t n)> reserve =
@@ -173,14 +179,25 @@ struct export_vector_types
             [] (vector<ValueType>& v) -> bool { return v.empty(); };
         std::function<void(vector<ValueType>&)> clear =
             [] (vector<ValueType>& v) { v.clear(); };
-        vc.def(vector_indexing_suite<vector<ValueType> >())
-            .def("__eq__", &vector_equal_compare<ValueType>)
-            .def("__ne__", &vector_nequal_compare<ValueType>)
-            .def("__hash__", hasher)
+        vc.def(vector_indexing_suite<vector<ValueType>>())
             .def("resize", resize)
             .def("shrink_to_fit", shrink_to_fit)
             .def("clear", clear)
             .def("empty", empty);
+
+        if constexpr (comparable)
+        {
+            vc.def("__eq__", &vector_equal_compare<ValueType>);
+            vc.def("__ne__", &vector_nequal_compare<ValueType>);
+        }
+        if constexpr (hashable)
+        {
+            std::function<size_t(const vector<ValueType>&)> hasher =
+                [] (const vector<ValueType>& v) -> size_t
+                { return std::hash<vector<ValueType>>()(v); };
+            vc.def("__hash__", hasher);
+        }
+
         wrap_array(vc, typename boost::mpl::has_key<numpy_types,ValueType>::type());
         vector_from_list<ValueType>();
     }
@@ -205,12 +222,14 @@ template <class Exception>
 void graph_exception_translator(const Exception& e)
 {
     PyObject* error;
-    if (std::is_same<Exception, GraphException>::value)
+    if constexpr (std::is_same_v<Exception, GraphException>)
         error = PyExc_RuntimeError;
-    if (std::is_same<Exception, IOException>::value)
+    else if constexpr (std::is_same_v<Exception, IOException>)
         error = PyExc_IOError;
-    if (std::is_same<Exception, ValueException>::value)
+    else if constexpr (std::is_same_v<Exception, ValueException>)
         error = PyExc_ValueError;
+    // else
+    //     static_assert(false);
     PyErr_SetString(error, e.what());
 }
 
@@ -382,7 +401,7 @@ void set_unpickler(boost::python::object o)
 boost::python::list get_property_types()
 {
     boost::python::list plist;
-    for (int i = 0; i < boost::mpl::size<value_types>::value; ++i)
+    for (size_t i = 0; i < hana::length(value_types).value; ++i)
         plist.append(string(type_names[i]));
     return plist;
 }
@@ -415,49 +434,41 @@ size_t get_ptr(std::shared_ptr<GraphInterface::multigraph_t>& p)
     return size_t(p.get());
 };
 
-
-// numpy array interface weirdness
-void* do_import_array()
-{
-    import_array1(NULL);
-    return NULL;
-}
-
-void ungroup_vector_property(GraphInterface& g, boost::any vector_prop,
-                             boost::any prop, size_t pos, bool edge);
-void group_vector_property(GraphInterface& g, boost::any vector_prop,
-                           boost::any prop, size_t pos, bool edge);
-void property_map_values(GraphInterface& g, boost::any src_prop,
-                         boost::any tgt_prop, boost::python::object mapper,
+void ungroup_vector_property(GraphInterface& g, std::any vector_prop,
+                             std::any prop, size_t pos, bool edge);
+void group_vector_property(GraphInterface& g, std::any vector_prop,
+                           std::any prop, size_t pos, bool edge);
+void property_map_values(GraphInterface& g, std::any src_prop,
+                         std::any tgt_prop, boost::python::object mapper,
                          bool edge);
-void infect_vertex_property(GraphInterface& gi, boost::any prop,
+void infect_vertex_property(GraphInterface& gi, std::any prop,
                             boost::python::object val);
-void edge_endpoint(GraphInterface& gi, boost::any prop,
-                   boost::any eprop, std::string endpoint);
-void out_edges_op(GraphInterface& gi, boost::any eprop, boost::any vprop,
+void edge_endpoint(GraphInterface& gi, std::any prop,
+                   std::any eprop, std::string endpoint);
+void out_edges_op(GraphInterface& gi, std::any eprop, std::any vprop,
                   std::string op);
-void mark_edges(GraphInterface& gi, boost::any prop);
+void mark_edges(GraphInterface& gi, std::any prop);
 
-void perfect_ehash(GraphInterface& gi, boost::any prop, boost::any hprop,
-                   boost::any& dict);
-void perfect_vhash(GraphInterface& gi, boost::any prop, boost::any hprop,
-                   boost::any& dict);
-void set_vertex_property(GraphInterface& gi, boost::any prop,
+void perfect_ehash(GraphInterface& gi, std::any prop, std::any hprop,
+                   std::any& dict);
+void perfect_vhash(GraphInterface& gi, std::any prop, std::any hprop,
+                   std::any& dict);
+void set_vertex_property(GraphInterface& gi, std::any prop,
                          boost::python::object val);
-void set_edge_property(GraphInterface& gi, boost::any prop,
+void set_edge_property(GraphInterface& gi, std::any prop,
                        boost::python::object val);
 
 void copy_external_edge_property(const GraphInterface& src,
                                  const GraphInterface& tgt,
-                                 boost::any prop_src,
-                                 boost::any prop_tgt);
+                                 std::any prop_src,
+                                 std::any prop_tgt);
 
 bool compare_vertex_properties(const GraphInterface& gi,
-                               boost::any prop1,
-                               boost::any prop2);
+                               std::any prop1,
+                               std::any prop2);
 bool compare_edge_properties(const GraphInterface& gi,
-                             boost::any prop1,
-                             boost::any prop2);
+                             std::any prop1,
+                             std::any prop2);
 
 void export_python_interface();
 
@@ -468,7 +479,7 @@ BOOST_PYTHON_MODULE(libgraph_tool_core)
     python::docstring_options dopt(true, false);
 
     // numpy
-    do_import_array();
+    PyArray_ImportNumPyAPI();
     export_python_interface();
 
     // random numbers
@@ -485,22 +496,23 @@ BOOST_PYTHON_MODULE(libgraph_tool_core)
 
     def("raise_error", &raise_error);
     def("get_property_types", &get_property_types);
-    class_<boost::any>("any")
-        .def("empty", &boost::any::empty)
-        .def("type",  &boost::any::type,
+    class_<std::any>("any")
+        .def("has_value", &std::any::has_value)
+        .def("type",  &std::any::type,
              return_value_policy<reference_existing_object>());
     class_<std::type_info, boost::noncopyable>("type_info", no_init)
         .def("name", &std::type_info::name)
         .def("hash_code", &std::type_info::hash_code);
     def("name_demangle", &name_demangle);
 
-    def("graph_filtering_enabled", &graph_filtering_enabled);
     export_openmp();
 
-    boost::mpl::for_each<boost::mpl::push_back<scalar_types,string>::type>(export_vector_types());
-    export_vector_types()(size_t(), "size_t");
-    export_vector_types()(std::vector<double>(), "Vector_double");
-    export_vector_types()(std::complex<double>(), "cdouble");
+    boost::hana::for_each(boost::hana::append(scalar_types,boost::hana::type<string>()),
+                          [](auto t){export_vector_types<>()(typename decltype(+t)::type());});
+    export_vector_types<>()(size_t(), "size_t");
+    export_vector_types<>()(std::vector<double>(), "Vector_double");
+    export_vector_types<false,false>()(std::any(), "any");
+    export_vector_types<>()(std::complex<double>(), "cdouble");
 
     class_<GraphInterface>("GraphInterface", init<>())
         .def(init<GraphInterface,bool,boost::python::object,
@@ -513,6 +525,8 @@ BOOST_PYTHON_MODULE(libgraph_tool_core)
         .def("get_reversed", &GraphInterface::get_reversed)
         .def("set_keep_epos", &GraphInterface::set_keep_epos)
         .def("get_keep_epos", &GraphInterface::get_keep_epos)
+        .def("set_keep_ehash", &GraphInterface::set_keep_ehash)
+        .def("get_keep_ehash", &GraphInterface::get_keep_ehash)
         .def("set_vertex_filter_property",
              &GraphInterface::set_vertex_filter_property)
         .def("is_vertex_filter_active", &GraphInterface::is_vertex_filter_active)
@@ -549,7 +563,7 @@ BOOST_PYTHON_MODULE(libgraph_tool_core)
         .value("Out", GraphInterface::OUT_DEGREE)
         .value("Total", GraphInterface::TOTAL_DEGREE);
 
-    variant_from_python<boost::any>();
+    variant_from_python<std::any>();
     variant_from_python<GraphInterface::degree_t>();
     to_python_converter<pair<string,bool>, pair_to_tuple<string,bool> >();
     to_python_converter<pair<size_t,size_t>, pair_to_tuple<size_t,size_t> >();
