@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -22,7 +22,7 @@
 
 #include "graph_blockmodel_util.hh"
 #include "graph_blockmodel.hh"
-#include "../uncertain/graph_blockmodel_sample_edge.hh"
+#include "../uncertain/sample_edge_sbm.hh"
 #include "../support/graph_state.hh"
 
 using namespace boost;
@@ -62,7 +62,7 @@ REGISTER_MOD
              double (state_t::*get_move_prob)(size_t, size_t, size_t, double,
                                               double, bool) =
                  &state_t::get_move_prob;
-             void (state_t::*set_partition)(boost::any&) =
+             void (state_t::*set_partition)(std::any&) =
                  &state_t::set_partition;
 
              class_<state_t, bases<BlockStateVirtualBase>, std::shared_ptr<state_t>>
@@ -99,7 +99,12 @@ REGISTER_MOD
                  .def("get_edge_sampler",
                       +[](state_t& state, bool edges_only)
                       {
-                          return make_shared<SBMEdgeSampler<state_t>>(state, edges_only);
+                          return make_shared<SBMEdgeSampler<state_t>>(state, edges_only ? 1. : 0.25);
+                      })
+                 .def("get_any",
+                      +[](state_t& state)
+                      {
+                          return std::any(&state);
                       });
 
              typedef SBMEdgeSampler<state_t> edge_sampler_t;
@@ -116,6 +121,26 @@ REGISTER_MOD
                       +[](edge_sampler_t& es, size_t u, size_t v, size_t m)
                       {
                           return es.log_prob(u, v, m, 0);
+                      })
+                 .def("sample_out_neighbor",
+                      +[](edge_sampler_t& es, size_t v, rng_t& rng)
+                      {
+                          return es.sample_out_neighbor(v, rng);
+                      })
+                 .def("log_prob_out",
+                      +[](edge_sampler_t& es, size_t v, size_t u)
+                      {
+                          return es.log_prob_out(v, u);
+                      })
+                 .def("sample_in_neighbor",
+                      +[](edge_sampler_t& es, size_t v, rng_t& rng)
+                      {
+                          return es.sample_in_neighbor(v, rng);
+                      })
+                 .def("log_prob_in",
+                      +[](edge_sampler_t& es, size_t v, size_t u)
+                      {
+                          return es.log_prob_in(v, u);
                       });
          });
 }, 0);
