@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -61,7 +61,7 @@ REGISTER_MOD
              // double (state_t::*get_move_prob)(size_t, size_t, size_t, double,
              //                                  double, bool) =
              //     &state_t::get_move_prob;
-             // void (state_t::*set_partition)(boost::any&) =
+             // void (state_t::*set_partition)(std::any&) =
              //     &state_t::set_partition;
 
              class_<state_t, bases<BlockStateVirtualBase>, std::shared_ptr<state_t>>
@@ -70,7 +70,12 @@ REGISTER_MOD
              c.def("get_B_E",
                   &state_t::get_B_E)
                  .def("get_B_E_D",
-                      &state_t::get_B_E_D);
+                      &state_t::get_B_E_D)
+                 .def("get_any",
+                      +[](state_t& state)
+                      {
+                          return std::any(&state);
+                      });
              // c.def("remove_vertices", remove_vertices)
              //     .def("add_vertices", add_vertices)
              //     .def("move_vertex", move_vertex)
