@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -27,11 +27,11 @@ using namespace std;
 using namespace boost;
 using namespace graph_tool;
 
-void collect_vertex_marginals(GraphInterface& gi, boost::any ob,
-                              boost::any op, size_t update)
+void collect_vertex_marginals(GraphInterface& gi, std::any ob,
+                              std::any op, size_t update)
 {
-    typedef vprop_map_t<int32_t>::type vmap_t;
-    auto b = any_cast<vmap_t>(ob).get_unchecked();
+    typedef vprop_map_t<int32_t> vmap_t;
+    auto b = std::any_cast<vmap_t>(ob).get_unchecked();
 
     run_action<>()
         (gi, [&](auto& g, auto p)
@@ -49,7 +49,7 @@ void collect_vertex_marginals(GraphInterface& gi, boost::any ob,
                       pv[r] += up;
                   });
          },
-         vertex_scalar_vector_properties())(op);
+         vertex_scalar_vector_properties)(op);
 }
 
 class BlockPairHist
@@ -101,17 +101,17 @@ public:
 
 };
 
-void collect_edge_marginals(GraphInterface& gi, boost::any ob,
-                            boost::any op, size_t update)
+void collect_edge_marginals(GraphInterface& gi, std::any ob,
+                            std::any op, size_t update)
 {
-    typedef vprop_map_t<int32_t>::type vmap_t;
-    auto b = any_cast<vmap_t>(ob).get_unchecked();
+    typedef vprop_map_t<int32_t> vmap_t;
+    auto b = std::any_cast<vmap_t>(ob).get_unchecked();
 
-    typedef eprop_map_t<python::object>::type
+    typedef eprop_map_t<python::object>
         emap_t;
-    auto pe = any_cast<emap_t>(op).get_unchecked(gi.get_edge_index_range());
+    auto pe = std::any_cast<emap_t>(op).get_unchecked(gi.get_edge_index_range());
 
-    run_action<>()
+    run_action<>(false)
         (gi,
          [&](auto& g)
          {
@@ -133,7 +133,7 @@ void collect_edge_marginals(GraphInterface& gi, boost::any ob,
          })();
 }
 
-double mf_entropy(GraphInterface& gi, boost::any opv)
+double mf_entropy(GraphInterface& gi, std::any opv)
 {
     double H=0;
     run_action<>()
@@ -154,22 +154,22 @@ double mf_entropy(GraphInterface& gi, boost::any opv)
                  }
              }
          },
-         vertex_scalar_vector_properties())(opv);
+         vertex_scalar_vector_properties)(opv);
 
     return H;
 }
 
-boost::python::tuple bethe_entropy(GraphInterface& gi, boost::any op,
-                                   boost::any opv)
+boost::python::tuple bethe_entropy(GraphInterface& gi, std::any op,
+                                   std::any opv)
 {
-    typedef vprop_map_t<vector<double>>::type vmap_t;
-    vmap_t pv = any_cast<vmap_t>(opv);
+    typedef vprop_map_t<vector<double>> vmap_t;
+    vmap_t pv = std::any_cast<vmap_t>(opv);
 
-    typedef eprop_map_t<boost::python::object>::type emap_t;
-    auto pe = any_cast<emap_t>(op).get_unchecked();
+    typedef eprop_map_t<boost::python::object> emap_t;
+    auto pe = std::any_cast<emap_t>(op).get_unchecked();
 
     double H=0, Hmf=0;
-    run_action<>()
+    run_action<>(false)
         (gi,
          [&](auto& g)
          {
@@ -265,6 +265,7 @@ public:
 
 static double log_n_permutations(const vector<int32_t>& b)
 {
+    GILRelease gil_release;
     std::vector<int32_t> count(b.size());
     for (auto bi : b)
         count[bi]++;
@@ -276,6 +277,7 @@ static double log_n_permutations(const vector<int32_t>& b)
 
 static vector<int32_t> unlabel_partition(vector<int32_t> b)
 {
+    GILRelease gil_release;
     std::vector<int32_t> map(b.size(), -1);
     size_t pos = 0;
     for (auto& bi : b)
@@ -291,11 +293,11 @@ static vector<int32_t> unlabel_partition(vector<int32_t> b)
     return b;
 }
 
-void collect_partitions(boost::any& ob, PartitionHist& h, double update,
+void collect_partitions(std::any& ob, PartitionHist& h, double update,
                         bool unlabel)
 {
-    typedef vprop_map_t<int32_t>::type vmap_t;
-    auto& b = any_cast<vmap_t&>(ob);
+    typedef vprop_map_t<int32_t> vmap_t;
+    auto& b = std::any_cast<vmap_t&>(ob);
     auto& v = b.get_storage();
     if (unlabel)
     {
@@ -311,12 +313,12 @@ void collect_partitions(boost::any& ob, PartitionHist& h, double update,
 void collect_hierarchical_partitions(python::object ovb, PartitionHist& h,
                                      size_t update, bool unlabel)
 {
-    typedef vprop_map_t<int32_t>::type vmap_t;
+    typedef vprop_map_t<int32_t> vmap_t;
     vector<int32_t> v;
     for (int i = 0; i < len(ovb); ++i)
     {
-        boost::any& ob = python::extract<boost::any&>(ovb[i])();
-        auto& b = any_cast<vmap_t&>(ob);
+        std::any& ob = python::extract<std::any&>(ovb[i])();
+        auto& b = std::any_cast<vmap_t&>(ob);
         auto& vi = b.get_storage();
         v.reserve(v.size() + vi.size());
         if (unlabel)
