@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -24,21 +24,21 @@ using namespace std;
 using namespace boost;
 using namespace graph_tool;
 
-double modularity(GraphInterface& gi, double gamma, boost::any weight,
-                  boost::any property)
+double modularity(GraphInterface& gi, double gamma, std::any weight,
+                  std::any property)
 {
     double Q = 0;
 
     typedef UnityPropertyMap<int, GraphInterface::edge_t> weight_map_t;
-    typedef boost::mpl::push_back<edge_scalar_properties, weight_map_t>::type
-        edge_props_t;
+    auto edge_props_t = hana::append(edge_scalar_properties,
+                                     hana::type<weight_map_t>());
 
-    if(weight.empty())
+    if(!weight.has_value())
         weight = weight_map_t();
 
     run_action<>()
-        (gi, [&](auto& g, auto& w, auto& b){ Q = get_modularity(g, gamma, w, b);},
-         edge_props_t(), vertex_scalar_properties())
+        (gi, [&](auto& g, auto w, auto b){ Q = get_modularity(g, gamma, w, b);},
+         edge_props_t, vertex_scalar_properties)
         (weight, property);
 
     return Q;
