@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -67,7 +67,7 @@ REGISTER_MOD
                       double (state_t::*get_move_prob)(size_t, size_t, size_t, double,
                                                        double, bool)
                           = &state_t::get_move_prob;
-                      void (state_t::*set_partition)(boost::any&)
+                      void (state_t::*set_partition)(std::any&)
                           = &state_t::set_partition;
                       void (state_t::*move_vertices)(python::object, python::object) =
                           &state_t::move_vertices;
