@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -91,23 +91,23 @@ REGISTER_MOD
         .def("get_M", &PartitionModeState::get_M)
         .def("get_marginal",
              +[](PartitionModeState& state,
-                 GraphInterface& gi, boost::any obm)
+                 GraphInterface& gi, std::any obm)
               {
                   run_action<>()
                       (gi, [&](auto& g, auto bm)
                       {
                           state.get_marginal(g, bm);
-                      }, vertex_scalar_vector_properties())(obm);
+                      }, vertex_scalar_vector_properties)(obm);
               })
         .def("get_map",
              +[](PartitionModeState& state,
-                 GraphInterface& gi, boost::any ob)
+                 GraphInterface& gi, std::any ob)
               {
                   run_action<>()
                       (gi, [&](auto& g, auto b)
                       {
                           state.get_map(g, b);
-                      }, writable_vertex_scalar_properties())(ob);
+                      }, writable_vertex_scalar_properties)(ob);
               })
         .def("get_map_bs",
              +[](PartitionModeState& state)
@@ -212,6 +212,7 @@ REGISTER_MOD
          {
              auto x = get_array<int32_t, 1>(ox);
              auto y = get_array<int32_t, 1>(oy);
+             GILRelease gil_release;
              return partition_overlap(x, y);
          });
 
@@ -219,6 +220,7 @@ REGISTER_MOD
         +[](object ox, rng_t& rng)
          {
              auto x = get_array<int32_t, 1>(ox);
+             GILRelease gil_release;
              partition_shuffle_labels(x, rng);
          });
 
@@ -232,7 +234,10 @@ REGISTER_MOD
                  x.emplace_back(a.begin(), a.end());
              }
 
-             nested_partition_shuffle_labels(x, rng);
+             {
+                 GILRelease gil_release;
+                 nested_partition_shuffle_labels(x, rng);
+             }
 
              python::list onx;
              for (auto& xl : x)
@@ -245,6 +250,7 @@ REGISTER_MOD
         +[](object ox)
          {
              auto x = get_array<int32_t, 1>(ox);
+             GILRelease gil_release;
              partition_order_labels(x);
          });
 
@@ -258,7 +264,10 @@ REGISTER_MOD
                  x.emplace_back(a.begin(), a.end());
              }
 
-             nested_partition_order_labels(x);
+             {
+                 GILRelease gil_release;
+                 nested_partition_order_labels(x);
+             }
 
              python::list onx;
              for (auto& xl : x)
@@ -272,6 +281,7 @@ REGISTER_MOD
          {
              auto x = get_array<int32_t, 1>(ox);
              auto y = get_array<int32_t, 1>(oy);
+             GILRelease gil_release;
              partition_align_labels(x, y);
          });
 
@@ -291,7 +301,10 @@ REGISTER_MOD
                  y.emplace_back(a.begin(), a.end());
              }
 
-             nested_partition_align_labels(x, y);
+             {
+                 GILRelease gil_release;
+                 nested_partition_align_labels(x, y);
+             }
 
              python::list onx;
              for (auto& xl : x)
@@ -306,6 +319,7 @@ REGISTER_MOD
              auto c = get_array<int32_t, 1>(oc);
              auto bs = get_array<int32_t, 2>(obs);
 
+             GILRelease gil_release;
              return partition_overlap_center(c, bs);
          });
 
@@ -332,7 +346,9 @@ REGISTER_MOD
                  }
              }
 
+             GILRelease gil_release;
              double r = nested_partition_overlap_center(c, bs);
+             gil_release.restore();
 
              python::list onx;
              for (auto& xl : c)
@@ -371,14 +387,14 @@ REGISTER_MOD
          });
 
     def("get_contingency_graph",
-        +[](GraphInterface& gi, boost::any alabel,
-            boost::any amrs, boost::any apartition, object ox, object oy)
+        +[](GraphInterface& gi, std::any alabel,
+            std::any amrs, std::any apartition, object ox, object oy)
          {
              auto x = get_array<int32_t, 1>(ox);
              auto y = get_array<int32_t, 1>(oy);
-             auto label = any_cast<vprop_map_t<int32_t>::type>(alabel);
-             auto partition = any_cast<vprop_map_t<uint8_t>::type>(apartition);
-             auto mrs = any_cast<eprop_map_t<int32_t>::type>(amrs);
+             auto label = std::any_cast<vprop_map_t<int32_t>>(alabel);
+             auto partition = std::any_cast<vprop_map_t<uint8_t>>(apartition);
+             auto mrs = std::any_cast<eprop_map_t<int32_t>>(amrs);
              run_action<>()
                  (gi, [&](auto& g)
                   {
