@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -28,34 +28,34 @@ using namespace graph_tool;
 
 typedef Histogram<size_t, size_t, 1> hist_t;
 
-python::object distance_histogram(GraphInterface& gi, boost::any weight,
+python::object distance_histogram(GraphInterface& gi, std::any weight,
                                   const vector<long double>& bins)
 {
     python::object ret;
 
-    if (weight.empty())
+    if (!weight.has_value())
     {
-        run_action<>()
+        run_action<>(false)
             (gi,
              [&](auto&& graph)
              {
-                 return get_distance_histogram()
+                 get_distance_histogram()
                      (std::forward<decltype(graph)>(graph),
                       gi.get_vertex_index(), no_weightS(), bins, ret);
              })();
     }
     else
     {
-        run_action<>()
+        run_action<>(false)
             (gi,
              [&](auto&& graph, auto&& a2)
              {
-                 return get_distance_histogram()
+                 get_distance_histogram()
                      (std::forward<decltype(graph)>(graph),
                       gi.get_vertex_index(), std::forward<decltype(a2)>(a2),
                       bins, ret);
              },
-             edge_scalar_properties())(weight);
+             edge_scalar_properties)(weight);
     }
     return ret;
 }
