@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -29,9 +29,9 @@ using namespace graph_tool;
 
 struct deg_check : public boost::static_visitor<>
 {
-    void operator()(boost::any a) const
+    void operator()(std::any a) const
     {
-        if (!belongs<vertex_scalar_properties>()(a))
+        if (!belongs(vertex_scalar_properties, a))
             throw ValueException("Vertex property must be of scalar type.");
     }
 
@@ -39,7 +39,6 @@ struct deg_check : public boost::static_visitor<>
     void operator()(const T&) const {}
 };
 
-
 // this will return the vertex histogram of degrees or scalar properties
 python::object
 get_vertex_histogram(GraphInterface& gi, GraphInterface::deg_t deg,
@@ -50,18 +49,20 @@ get_vertex_histogram(GraphInterface& gi, GraphInterface::deg_t deg,
     python::object hist;
     python::object ret_bins;
 
-    run_action<>()(gi, get_histogram<VertexHistogramFiller>(hist, bins,
-                                                            ret_bins),
-         scalar_selectors())(degree_selector(deg));
+    run_action<>(false)
+        (gi,
+         get_histogram<VertexHistogramFiller>(hist, bins, ret_bins),
+         all_selectors)(degree_selector(deg));
+
     return python::make_tuple(hist, ret_bins);
 }
 
 // this will return the vertex histogram of degrees or scalar properties
 python::object
-get_edge_histogram(GraphInterface& gi, boost::any prop,
+get_edge_histogram(GraphInterface& gi, std::any prop,
                    const vector<long double>& bins)
 {
-    if (!belongs<edge_scalar_properties>()(prop))
+    if (!belongs(edge_scalar_properties, prop))
         throw ValueException("Edge property must be of scalar type.");
 
     python::object hist;
@@ -69,9 +70,9 @@ get_edge_histogram(GraphInterface& gi, boost::any prop,
 
     bool directed = gi.get_directed();
     gi.set_directed(true);
-    run_action<graph_tool::detail::always_directed>()
+    run_action<decltype(graph_tool::always_directed)>(false)
         (gi, get_histogram<EdgeHistogramFiller>(hist, bins, ret_bins),
-         edge_scalar_properties())(prop);
+         edge_scalar_properties)(prop);
     gi.set_directed(directed);
 
     return python::make_tuple(hist, ret_bins);
