@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -67,55 +67,64 @@ struct check_iso
     };
 };
 
-typedef property_map_types::apply<integer_types,
-                                  GraphInterface::vertex_index_map_t,
-                                  mpl::bool_<false> >::type
-    vertex_props_t;
-
 bool check_isomorphism(GraphInterface& gi1, GraphInterface& gi2,
-                       boost::any ainv_map1, boost::any ainv_map2,
-                       int64_t max_inv, boost::any aiso_map)
+                       std::any ainv_map1, std::any ainv_map2,
+                       int64_t max_inv, std::any aiso_map)
 {
     bool result;
 
-    typedef vprop_map_t<int32_t>::type iso_map_t;
-    auto iso_map = any_cast<iso_map_t>(aiso_map);
+    typedef vprop_map_t<int32_t> iso_map_t;
+    auto iso_map = std::any_cast<iso_map_t>(aiso_map);
 
-    typedef vprop_map_t<int64_t>::type inv_map_t;
-    auto inv_map1 = any_cast<inv_map_t>(ainv_map1);
-    auto inv_map2 = any_cast<inv_map_t>(ainv_map2);
+    typedef vprop_map_t<int64_t> inv_map_t;
+    auto inv_map1 = std::any_cast<inv_map_t>(ainv_map1);
+    auto inv_map2 = std::any_cast<inv_map_t>(ainv_map2);
 
     if (gi1.get_directed() != gi2.get_directed())
         return false;
     if (gi1.get_directed())
     {
         gt_dispatch<>()
-            (
-                [&](auto&& graph, auto&& a2)
-                {
-                    return check_iso()
-                        (std::forward<decltype(graph)>(graph),
-                         std::forward<decltype(a2)>(a2), inv_map1, inv_map2,
-                         max_inv, iso_map, gi1.get_vertex_index(),
-                         gi2.get_vertex_index(), result);
-                },
-                always_directed(),
-                always_directed())(gi1.get_graph_view(), gi2.get_graph_view());
+            ([&](auto&& graph, auto&& a2)
+             {
+                 vprop_map_t<size_t> imap(get(vertex_index, graph));
+
+                 check_iso()
+                     (std::forward<decltype(graph)>(graph),
+                      std::forward<decltype(a2)>(a2), inv_map1, inv_map2,
+                      max_inv, imap, gi1.get_vertex_index(),
+                      gi2.get_vertex_index(), result);
+
+                 if (result)
+                 {
+                     for (auto v : vertices_range(graph))
+                         iso_map[v] = imap[v];
+                 }
+             },
+             always_directed,
+             always_directed)(gi1.get_graph_view(), gi2.get_graph_view());
     }
     else
     {
         gt_dispatch<>()
-            (
-                [&](auto&& graph, auto&& a2)
-                {
-                    return check_iso()
-                        (std::forward<decltype(graph)>(graph),
-                         std::forward<decltype(a2)>(a2), inv_map1, inv_map2,
-                         max_inv, iso_map, gi1.get_vertex_index(),
-                         gi2.get_vertex_index(), result);
-                },
-                never_directed(),
-                never_directed())(gi1.get_graph_view(), gi2.get_graph_view());
+            ([&](auto&& graph, auto&& a2)
+             {
+                 vprop_map_t<size_t> imap(get(vertex_index, graph));
+
+                 check_iso()
+                     (std::forward<decltype(graph)>(graph),
+                      std::forward<decltype(a2)>(a2), inv_map1, inv_map2,
+                      max_inv, imap, gi1.get_vertex_index(),
+                      gi2.get_vertex_index(), result);
+
+                 if (result)
+                 {
+                     for (auto v : vertices_range(graph))
+                         iso_map[v] = imap[v];
+                 }
+             },
+             never_directed,
+             never_directed)(gi1.get_graph_view(), gi2.get_graph_view());
     }
 
     return result;
