@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -29,13 +29,13 @@ using namespace graph_tool;
 
 
 void get_max_matching(GraphInterface& gi, std::string initial_matching,
-                      boost::any omatching)
+                      std::any omatching)
 {
-    typedef typename vprop_map_t<int64_t>::type vprop_t;
+    typedef vprop_map_t<int64_t> vprop_t;
 
-    vprop_t::unchecked_t matching = any_cast<vprop_t>(omatching).get_unchecked();
+    vprop_t::unchecked_t matching = std::any_cast<vprop_t>(omatching).get_unchecked();
 
-    run_action<graph_tool::detail::never_directed>()
+    run_action<decltype(graph_tool::never_directed)>()
         (gi,
          [&](auto& g)
          {
@@ -71,21 +71,21 @@ void get_max_matching(GraphInterface& gi, std::string initial_matching,
          })();
 }
 
-void get_max_weighted_matching(GraphInterface& gi, boost::any oweight,
-                               boost::any omatching, bool brute_force)
+void get_max_weighted_matching(GraphInterface& gi, std::any oweight,
+                               std::any omatching, bool brute_force)
 {
-    typedef typename vprop_map_t<int64_t>::type vprop_t;
+    typedef vprop_map_t<int64_t> vprop_t;
 
-    vprop_t::unchecked_t matching = any_cast<vprop_t>(omatching).get_unchecked();
+    vprop_t::unchecked_t matching = std::any_cast<vprop_t>(omatching).get_unchecked();
 
-    run_action<graph_tool::detail::never_directed>()
+    run_action<decltype(graph_tool::never_directed)>()
         (gi,
          [&](auto& g, auto w)
          {
              typedef std::remove_reference_t<decltype(g)> g_t;
 
              typedef typename graph_traits<g_t>::vertex_descriptor vertex_t;
-             typename vprop_map_t<vertex_t>::type match(get(vertex_index,g));
+             vprop_map_t<vertex_t> match(get(vertex_index,g));
 
              if (brute_force)
                  brute_force_maximum_weighted_matching(g, w, match);
@@ -100,31 +100,31 @@ void get_max_weighted_matching(GraphInterface& gi, boost::any oweight,
                      matching[v] = match[v];
              }
          },
-         edge_scalar_properties())(oweight);
+         edge_scalar_properties)(oweight);
 }
 
-void get_max_bip_weighted_matching(GraphInterface& gi, boost::any opartition,
-                                   boost::any oweight, boost::any omatching)
+void get_max_bip_weighted_matching(GraphInterface& gi, std::any opartition,
+                                   std::any oweight, std::any omatching)
 {
-    typedef typename vprop_map_t<int64_t>::type vprop_t;
+    typedef vprop_map_t<int64_t> vprop_t;
 
-    vprop_t::unchecked_t matching = any_cast<vprop_t>(omatching).get_unchecked();
+    vprop_t::unchecked_t matching = std::any_cast<vprop_t>(omatching).get_unchecked();
 
     typedef UnityPropertyMap<int, GraphInterface::edge_t> ecmap_t;
-    typedef boost::mpl::push_back<edge_scalar_properties, ecmap_t>::type
-        weight_props_t;
+    auto weight_props_t = hana::append(edge_scalar_properties,
+                                       hana::type<ecmap_t>());
 
-    if (oweight.empty())
+    if (!oweight.has_value())
         oweight = ecmap_t();
 
-    run_action<graph_tool::detail::never_directed>()
+    run_action<decltype(graph_tool::never_directed)>()
         (gi,
          [&](auto& g, auto part, auto w)
          {
              typedef std::remove_reference_t<decltype(g)> g_t;
 
              typedef typename graph_traits<g_t>::vertex_descriptor vertex_t;
-             typename vprop_map_t<vertex_t>::type match(get(vertex_index,g));
+             vprop_map_t<vertex_t> match(get(vertex_index,g));
 
              maximum_bipartite_weighted_matching(g, part, w, match);
 
@@ -136,19 +136,19 @@ void get_max_bip_weighted_matching(GraphInterface& gi, boost::any opartition,
                      matching[v] = match[v];
              }
          },
-         vertex_properties(), weight_props_t())(opartition, oweight);
+         vertex_properties, weight_props_t)(opartition, oweight);
 }
 
-void match_edges(GraphInterface& gi, boost::any omatching,
-                 boost::any oematching)
+void match_edges(GraphInterface& gi, std::any omatching,
+                 std::any oematching)
 {
-    typedef typename vprop_map_t<int64_t>::type vprop_t;
-    typedef typename eprop_map_t<uint8_t>::type eprop_t;
+    typedef vprop_map_t<int64_t> vprop_t;
+    typedef eprop_map_t<uint8_t> eprop_t;
 
-    vprop_t::unchecked_t matching = any_cast<vprop_t>(omatching).get_unchecked();
-    eprop_t::unchecked_t ematching = any_cast<eprop_t>(oematching).get_unchecked();
+    vprop_t::unchecked_t matching = std::any_cast<vprop_t>(omatching).get_unchecked();
+    eprop_t::unchecked_t ematching = std::any_cast<eprop_t>(oematching).get_unchecked();
 
-    run_action<graph_tool::detail::never_directed>()
+    run_action<decltype(graph_tool::never_directed)>()
         (gi,
          [&](auto& g)
          {
