@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -71,22 +71,18 @@ struct get_random_span_tree
     }
 };
 
-typedef property_map_types::apply<mpl::vector<uint8_t>,
-                                  GraphInterface::edge_index_map_t,
-                                  mpl::bool_<false> >::type
-    tree_properties;
-
 void get_random_spanning_tree(GraphInterface& gi, size_t root,
-                              boost::any weight_map, boost::any tree_map,
+                              std::any weight_map, std::any tree_map,
                               rng_t& rng)
 {
     typedef UnityPropertyMap<size_t,GraphInterface::edge_t> cweight_t;
 
-    if (weight_map.empty())
+    if (!weight_map.has_value())
         weight_map = cweight_t();
 
-    typedef mpl::push_back<writable_edge_scalar_properties, cweight_t>::type
-        weight_maps;
+    auto weight_maps = hana::append(writable_edge_scalar_properties,
+                                    hana::type<cweight_t>());
+    auto tree_properties = hana::tuple_t<eprop_map_t<uint8_t>>;
 
     run_action<>()
         (gi,
@@ -97,7 +93,7 @@ void get_random_spanning_tree(GraphInterface& gi, size_t root,
                   gi.get_vertex_index(), std::forward<decltype(a2)>(a2),
                   std::forward<decltype(a3)>(a3), rng);
          },
-         weight_maps(), tree_properties())(weight_map, tree_map);
+         weight_maps, tree_properties)(weight_map, tree_map);
 }
 
 #include <boost/python.hpp>
