@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -27,17 +27,17 @@ using namespace boost;
 using namespace graph_tool;
 
 typedef UnityPropertyMap<int64_t, GraphInterface::edge_t> ecmap_t;
-typedef boost::mpl::push_back<edge_scalar_properties, ecmap_t>::type
-        weight_props_t;
+inline constexpr auto weight_props_t = hana::append(edge_scalar_properties,
+                                                    hana::type<ecmap_t>());
 
 
-void get_dice_similarity(GraphInterface& gi, boost::any as, boost::any weight)
+void get_dice_similarity(GraphInterface& gi, std::any as, std::any weight)
 {
-    if (weight.empty())
+    if (!weight.has_value())
         weight = ecmap_t();
 
     gt_dispatch<>()
-        ([&](auto& g, auto& s, auto& w)
+        ([&](auto& g, auto s, auto w)
          {
              all_pairs_similarity(g, s,
                                   [&](auto u, auto v, auto& mask, auto& w)
@@ -45,18 +45,18 @@ void get_dice_similarity(GraphInterface& gi, boost::any as, boost::any weight)
                                       return dice(u, v, mask, w, g);
                                   }, w);
          },
-         all_graph_views(), vertex_floating_vector_properties(),
-         weight_props_t())
+         all_graph_views, vertex_floating_vector_properties,
+         weight_props_t)
         (gi.get_graph_view(), as, weight);
 }
 
-void get_salton_similarity(GraphInterface& gi, boost::any as, boost::any weight)
+void get_salton_similarity(GraphInterface& gi, std::any as, std::any weight)
 {
-    if (weight.empty())
+    if (!weight.has_value())
         weight = ecmap_t();
 
     gt_dispatch<>()
-        ([&](auto& g, auto& s, auto& w)
+        ([&](auto& g, auto s, auto w)
          {
              all_pairs_similarity(g, s,
                                   [&](auto u, auto v, auto& mask, auto& w)
@@ -64,18 +64,18 @@ void get_salton_similarity(GraphInterface& gi, boost::any as, boost::any weight)
                                       return salton(u, v, mask, w, g);
                                   }, w);
          },
-         all_graph_views(), vertex_floating_vector_properties(),
-         weight_props_t())
+         all_graph_views, vertex_floating_vector_properties,
+         weight_props_t)
         (gi.get_graph_view(), as, weight);
 }
 
-void get_hub_promoted_similarity(GraphInterface& gi, boost::any as, boost::any weight)
+void get_hub_promoted_similarity(GraphInterface& gi, std::any as, std::any weight)
 {
-    if (weight.empty())
+    if (!weight.has_value())
         weight = ecmap_t();
 
     gt_dispatch<>()
-        ([&](auto& g, auto& s, auto& w)
+        ([&](auto& g, auto s, auto w)
          {
              all_pairs_similarity(g, s,
                                   [&](auto u, auto v, auto& mask, auto& w)
@@ -83,18 +83,18 @@ void get_hub_promoted_similarity(GraphInterface& gi, boost::any as, boost::any w
                                       return hub_promoted(u, v, mask, w, g);
                                   }, w);
          },
-         all_graph_views(), vertex_floating_vector_properties(),
-         weight_props_t())
+         all_graph_views, vertex_floating_vector_properties,
+         weight_props_t)
         (gi.get_graph_view(), as, weight);
 }
 
-void get_hub_suppressed_similarity(GraphInterface& gi, boost::any as, boost::any weight)
+void get_hub_suppressed_similarity(GraphInterface& gi, std::any as, std::any weight)
 {
-    if (weight.empty())
+    if (!weight.has_value())
         weight = ecmap_t();
 
     gt_dispatch<>()
-        ([&](auto& g, auto& s, auto& w)
+        ([&](auto& g, auto s, auto w)
          {
              all_pairs_similarity(g, s,
                                   [&](auto u, auto v, auto& mask, auto& w)
@@ -102,18 +102,18 @@ void get_hub_suppressed_similarity(GraphInterface& gi, boost::any as, boost::any
                                       return hub_suppressed(u, v, mask, w, g);
                                   }, w);
          },
-         all_graph_views(), vertex_floating_vector_properties(),
-         weight_props_t())
+         all_graph_views, vertex_floating_vector_properties,
+         weight_props_t)
         (gi.get_graph_view(), as, weight);
 }
 
 void get_dice_similarity_pairs(GraphInterface& gi, python::object opairs,
-                               python::object osim, boost::any weight)
+                               python::object osim, std::any weight)
 {
     multi_array_ref<int64_t,2> pairs = get_array<int64_t,2>(opairs);
     multi_array_ref<double,1> sim = get_array<double,1>(osim);
 
-    if (weight.empty())
+    if (!weight.has_value())
         weight = ecmap_t();
 
     gt_dispatch<>()
@@ -125,17 +125,17 @@ void get_dice_similarity_pairs(GraphInterface& gi, python::object opairs,
                                        return dice(u, v, mask, w, g);
                                    }, w);
          },
-         all_graph_views(), weight_props_t())
+         all_graph_views, weight_props_t)
         (gi.get_graph_view(), weight);
 }
 
 void get_salton_similarity_pairs(GraphInterface& gi, python::object opairs,
-                                 python::object osim, boost::any weight)
+                                 python::object osim, std::any weight)
 {
     multi_array_ref<int64_t,2> pairs = get_array<int64_t,2>(opairs);
     multi_array_ref<double,1> sim = get_array<double,1>(osim);
 
-    if (weight.empty())
+    if (!weight.has_value())
         weight = ecmap_t();
 
     gt_dispatch<>()
@@ -147,17 +147,17 @@ void get_salton_similarity_pairs(GraphInterface& gi, python::object opairs,
                                        return salton(u, v, mask, w, g);
                                    }, w);
          },
-         all_graph_views(), weight_props_t())
+         all_graph_views, weight_props_t)
         (gi.get_graph_view(), weight);
 }
 
 void get_hub_promoted_similarity_pairs(GraphInterface& gi, python::object opairs,
-                                       python::object osim, boost::any weight)
+                                       python::object osim, std::any weight)
 {
     multi_array_ref<int64_t,2> pairs = get_array<int64_t,2>(opairs);
     multi_array_ref<double,1> sim = get_array<double,1>(osim);
 
-    if (weight.empty())
+    if (!weight.has_value())
         weight = ecmap_t();
 
     gt_dispatch<>()
@@ -169,17 +169,17 @@ void get_hub_promoted_similarity_pairs(GraphInterface& gi, python::object opairs
                                        return hub_promoted(u, v, mask, w, g);
                                    }, w);
          },
-         all_graph_views(), weight_props_t())
+         all_graph_views, weight_props_t)
         (gi.get_graph_view(), weight);
 }
 
 void get_hub_suppressed_similarity_pairs(GraphInterface& gi, python::object opairs,
-                                       python::object osim, boost::any weight)
+                                       python::object osim, std::any weight)
 {
     multi_array_ref<int64_t,2> pairs = get_array<int64_t,2>(opairs);
     multi_array_ref<double,1> sim = get_array<double,1>(osim);
 
-    if (weight.empty())
+    if (!weight.has_value())
         weight = ecmap_t();
 
     gt_dispatch<>()
@@ -191,17 +191,17 @@ void get_hub_suppressed_similarity_pairs(GraphInterface& gi, python::object opai
                                        return hub_suppressed(u, v, mask, w, g);
                                    }, w);
          },
-         all_graph_views(), weight_props_t())
+         all_graph_views, weight_props_t)
         (gi.get_graph_view(), weight);
 }
 
-void get_jaccard_similarity(GraphInterface& gi, boost::any as, boost::any weight)
+void get_jaccard_similarity(GraphInterface& gi, std::any as, std::any weight)
 {
-    if (weight.empty())
+    if (!weight.has_value())
         weight = ecmap_t();
 
     gt_dispatch<>()
-        ([&](auto& g, auto& s, auto w)
+        ([&](auto& g, auto s, auto w)
          {
              all_pairs_similarity(g, s,
                                   [&](auto u, auto v, auto& mask, auto w)
@@ -209,18 +209,18 @@ void get_jaccard_similarity(GraphInterface& gi, boost::any as, boost::any weight
                                       return jaccard(u, v, mask, w, g);
                                   }, w);
          },
-         all_graph_views(), vertex_floating_vector_properties(),
-         weight_props_t())
+         all_graph_views, vertex_floating_vector_properties,
+         weight_props_t)
         (gi.get_graph_view(), as, weight);
 }
 
 void get_jaccard_similarity_pairs(GraphInterface& gi, python::object opairs,
-                                  python::object osim, boost::any weight)
+                                  python::object osim, std::any weight)
 {
     multi_array_ref<int64_t,2> pairs = get_array<int64_t,2>(opairs);
     multi_array_ref<double,1> sim = get_array<double,1>(osim);
 
-    if (weight.empty())
+    if (!weight.has_value())
         weight = ecmap_t();
 
     gt_dispatch<>()
@@ -232,18 +232,18 @@ void get_jaccard_similarity_pairs(GraphInterface& gi, python::object opairs,
                                        return jaccard(u, v, mask, w, g);
                                    }, w);
          },
-         all_graph_views(), weight_props_t())
+         all_graph_views, weight_props_t)
         (gi.get_graph_view(), weight);
 }
 
-void get_inv_log_weight_similarity(GraphInterface& gi, boost::any as,
-                                   boost::any weight)
+void get_inv_log_weight_similarity(GraphInterface& gi, std::any as,
+                                   std::any weight)
 {
-    if (weight.empty())
+    if (!weight.has_value())
         weight = ecmap_t();
 
     gt_dispatch<>()
-        ([&](auto& g, auto& s, auto w)
+        ([&](auto& g, auto s, auto w)
          {
              all_pairs_similarity(g, s,
                                   [&](auto u, auto v, auto& mask, auto w)
@@ -251,20 +251,20 @@ void get_inv_log_weight_similarity(GraphInterface& gi, boost::any as,
                                       return inv_log_weighted(u, v, mask, w, g);
                                   }, w);
          },
-         all_graph_views(), vertex_floating_vector_properties(),
-         weight_props_t())
+         all_graph_views, vertex_floating_vector_properties,
+         weight_props_t)
         (gi.get_graph_view(), as, weight);
 }
 
 void get_inv_log_weight_similarity_pairs(GraphInterface& gi,
                                          python::object opairs,
                                          python::object osim,
-                                         boost::any weight)
+                                         std::any weight)
 {
     multi_array_ref<int64_t,2> pairs = get_array<int64_t,2>(opairs);
     multi_array_ref<double,1> sim = get_array<double,1>(osim);
 
-    if (weight.empty())
+    if (!weight.has_value())
         weight = ecmap_t();
 
     gt_dispatch<>()
@@ -276,18 +276,18 @@ void get_inv_log_weight_similarity_pairs(GraphInterface& gi,
                                        return inv_log_weighted(u, v, mask, w, g);
                                    }, w);
          },
-         all_graph_views(), weight_props_t())
+         all_graph_views, weight_props_t)
         (gi.get_graph_view(), weight);
 }
 
-void get_r_allocation_similarity(GraphInterface& gi, boost::any as,
-                                 boost::any weight)
+void get_r_allocation_similarity(GraphInterface& gi, std::any as,
+                                 std::any weight)
 {
-    if (weight.empty())
+    if (!weight.has_value())
         weight = ecmap_t();
 
     gt_dispatch<>()
-        ([&](auto& g, auto& s, auto w)
+        ([&](auto& g, auto s, auto w)
          {
              all_pairs_similarity(g, s,
                                   [&](auto u, auto v, auto& mask, auto w)
@@ -295,20 +295,20 @@ void get_r_allocation_similarity(GraphInterface& gi, boost::any as,
                                       return r_allocation(u, v, mask, w, g);
                                   }, w);
          },
-         all_graph_views(), vertex_floating_vector_properties(),
-         weight_props_t())
+         all_graph_views, vertex_floating_vector_properties,
+         weight_props_t)
         (gi.get_graph_view(), as, weight);
 }
 
 void get_r_allocation_similarity_pairs(GraphInterface& gi,
                                        python::object opairs,
                                        python::object osim,
-                                       boost::any weight)
+                                       std::any weight)
 {
     multi_array_ref<int64_t,2> pairs = get_array<int64_t,2>(opairs);
     multi_array_ref<double,1> sim = get_array<double,1>(osim);
 
-    if (weight.empty())
+    if (!weight.has_value())
         weight = ecmap_t();
 
     gt_dispatch<>()
@@ -320,18 +320,18 @@ void get_r_allocation_similarity_pairs(GraphInterface& gi,
                                        return r_allocation(u, v, mask, w, g);
                                    }, w);
          },
-         all_graph_views(), weight_props_t())
+         all_graph_views, weight_props_t)
         (gi.get_graph_view(), weight);
 }
 
-void get_leicht_holme_newman_similarity(GraphInterface& gi, boost::any as,
-                                 boost::any weight)
+void get_leicht_holme_newman_similarity(GraphInterface& gi, std::any as,
+                                 std::any weight)
 {
-    if (weight.empty())
+    if (!weight.has_value())
         weight = ecmap_t();
 
     gt_dispatch<>()
-        ([&](auto& g, auto& s, auto w)
+        ([&](auto& g, auto s, auto w)
          {
              all_pairs_similarity(g, s,
                                   [&](auto u, auto v, auto& mask, auto w)
@@ -339,20 +339,20 @@ void get_leicht_holme_newman_similarity(GraphInterface& gi, boost::any as,
                                       return leicht_holme_newman(u, v, mask, w, g);
                                   }, w);
          },
-         all_graph_views(), vertex_floating_vector_properties(),
-         weight_props_t())
+         all_graph_views, vertex_floating_vector_properties,
+         weight_props_t)
         (gi.get_graph_view(), as, weight);
 }
 
 void get_leicht_holme_newman_similarity_pairs(GraphInterface& gi,
                                               python::object opairs,
                                               python::object osim,
-                                              boost::any weight)
+                                              std::any weight)
 {
     multi_array_ref<int64_t,2> pairs = get_array<int64_t,2>(opairs);
     multi_array_ref<double,1> sim = get_array<double,1>(osim);
 
-    if (weight.empty())
+    if (!weight.has_value())
         weight = ecmap_t();
 
     gt_dispatch<>()
@@ -364,7 +364,7 @@ void get_leicht_holme_newman_similarity_pairs(GraphInterface& gi,
                                        return leicht_holme_newman(u, v, mask, w, g);
                                    }, w);
          },
-         all_graph_views(), weight_props_t())
+         all_graph_views, weight_props_t)
         (gi.get_graph_view(), weight);
 }
 
