@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -25,10 +25,8 @@ from .. generation import condensation_graph, random_rewire, generate_sbm, \
     solve_sbm_fugacities, generate_maxent_sbm, remove_parallel_edges, \
     remove_self_loops
 from .. spectral import adjacency
-import random
-from numpy import *
+import numpy as np
 import math
-import numpy
 import copy
 import collections.abc
 import itertools
@@ -49,52 +47,33 @@ def get_block_graph(g, B, b, vcount=None, ecount=None, rec=None, drec=None):
         ecount = None
     if isinstance(vcount, libinference.unity_vprop_t):
         vcount = None
-    avprops = []
-    if vcount is not None:
-        avprops.append(vcount)
-    aeprops = []
-    if ecount is not None:
-        aeprops.append(ecount)
+
+    aprops = []
     if rec is not None:
         for r in rec:
-            aeprops.append(r)
+            aprops.append(r)
     if drec is not None:
         for r in drec:
-            aeprops.append(r)
-    cg, br, vc, ec, av, ae = condensation_graph(g, b,
-                                                avprops=avprops,
-                                                aeprops=aeprops,
-                                                self_loops=True)
-    if vcount is not None:
-        vcount = av[0]
-        del av[0]
-    else:
-        vcount = vc
-    cg.vp.count = vcount
+            aprops.append(r)
 
-    if ecount is not None:
-        ecount = ae[0]
-        del ae[0]
-    else:
-        ecount = ec
+    cg, vcount, ecount, ap = condensation_graph(g, b, eweight=ecount,
+                                                vweight=vcount,
+                                                aprops=aprops)
+
+    cg.vp.count = vcount
     cg.ep.count = ecount
 
     if rec is not None:
         for i in range(len(rec)):
-            cg.ep["rec%d" % i] = ae[0]
-            del ae[0]
+            cg.ep["rec%d" % i] = ap[0]
+            del ap[0]
 
     if drec is not None:
         for i in range(len(drec)):
-            cg.ep["drec%d" % i] = ae[0]
-            del ae[0]
+            cg.ep["drec%d" % i] = ap[0]
+            del ap[0]
 
-    rs = numpy.setdiff1d(numpy.arange(B, dtype="int"), br.fa,
-                         assume_unique=True)
-    if len(rs) > 0:
-        cg.add_vertex(len(rs))
-        br.fa[-len(rs):] = rs
-    cg = Graph(cg, vorder=br)
+    cg.add_vertex(B - cg.num_vertices())
 
     cg.gp.rec = cg.new_gp("object", [])
     if rec is not None:
@@ -116,6 +95,7 @@ def init_q_cache(max_n=None):
         max_n = _q_cache_max_n
     libinference.init_q_cache(min((_q_cache_max_n, max_n)))
 
+@entropy_state_signature
 class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
                  GibbsMCMCState, MulticanonicalMCMCState, ExhaustiveSweepState,
                  DrawBlockState):
@@ -195,11 +175,17 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
     dense_bg : ``bool`` (optional, default: ``False``)
         If ``True`` a dense matrix is used for the block graph, otherwise a
         sparse matrix will be used.
+    entropy_args: ``dict`` (optional, default: ``{}``)
+        Override default arguments for :meth:`~BlockState.entropy()` method and
+        releated operations.
     """
 
     def __init__(self, g, b=None, B=None, eweight=None, vweight=None, recs=[],
                  rec_types=[], rec_params=[], clabel=None, pclabel=None,
-                 bfield=None, Bfield=None, deg_corr=True, dense_bg=False, **kwargs):
+                 bfield=None, Bfield=None, deg_corr=True, dense_bg=False,
+                 entropy_args={}, **kwargs):
+        EntropyState.__init__(self, entropy_args=entropy_args)
+
         kwargs = kwargs.copy()
 
         if eweight is None:
@@ -243,18 +229,18 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
             if B is None:
                 raise ValueError("either 'b' or 'B' must be specified")
             B = min((B, self.g.num_vertices()))
-            ba = random.randint(0, B, self.g.num_vertices())
-            ba[:B] = arange(B)        # avoid empty blocks
+            ba = np.random.randint(0, B, self.g.num_vertices())
+            ba[:B] = np.arange(B)        # avoid empty blocks
             if B < self.g.num_vertices():
-                random.shuffle(ba)
+                np.random.shuffle(ba)
             b = g.new_vp("int")
             b.fa = ba
             self.b = b
         else:
             # if a partition is available, we will incorporate it.
-            if isinstance(b, numpy.ndarray):
+            if isinstance(b, np.ndarray):
                 self.b = g.new_vp("int")
-                ba = numpy.zeros(len(self.b.fa), dtype="int")
+                ba = np.zeros(len(self.b.fa), dtype="int")
                 ba[:min((len(ba), len(b)))] = b[:min((len(ba), len(b)))]
                 self.b.fa = ba
             else:
@@ -270,7 +256,7 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
         if self.drec is None:
             self.drec = []
             for rec in self.rec:
-                self.drec.append(self.g.new_ep("double", rec.fa ** 2))
+                self.drec.append(self.g.new_ep("double", vals=rec.fa ** 2))
         else:
             if (isinstance(self.drec, PropertyMap) and
                 self.drec.value_type() == "vector<double>"):
@@ -289,7 +275,7 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
             rec_types.insert(0, libinference.rec_type.count)
             rec_params.insert(0, {})
             if isinstance(self.eweight, libinference.unity_eprop_t):
-                self.rec.insert(0, self.g.new_ep("double", 1))
+                self.rec.insert(0, self.g.new_ep("double", val=1))
             else:
                 self.rec.insert(0, self.eweight.copy("double"))
             self.drec.insert(0, self.g.new_ep("double"))
@@ -356,8 +342,8 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
             for i in range(len(self.rec)):
                 idx = self.rec[i].a != 0
                 if not isinstance(self.eweight, libinference.unity_eprop_t):
-                    idx = numpy.logical_and(idx, self.eweight.a > 0)
-                if numpy.any(idx):
+                    idx = np.logical_and(idx, self.eweight.a > 0)
+                if np.any(idx):
                     self.epsilon[i] = abs(self.rec[i].a[idx]).min() / 10
 
         self.bfield = g.new_vp("vector<double>") if bfield is None else self.g.own_property(bfield)
@@ -374,18 +360,12 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
         self._state = libinference.make_block_state(self)
         self.bg.properties.clear()
 
-        assert all(self.recdx.a >= 0), self.recdx.a
+        if _bm_test():
+            assert all(self.recdx.a >= 0), self.recdx.a
 
         if deg_corr:
             init_q_cache(max((2 * max((self.get_E(), self.get_N())), 100)))
 
-        self._entropy_args = dict(adjacency=True, deg_entropy=True, dl=True,
-                                  partition_dl=True, degree_dl=True,
-                                  degree_dl_kind="distributed", edges_dl=True,
-                                  dense=False, multigraph=True, exact=True,
-                                  recs=True, recs_dl=True, beta_dl=1.,
-                                  Bfield=True)
-
         if len(kwargs) > 0:
             warnings.warn("unrecognized keyword arguments: " +
                           str(list(kwargs.keys())))
@@ -429,8 +409,8 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
                     defaults = {"alpha": 1,
                                 "beta": self.rec[i].fa.mean()}
                 else:
-                    defaults = {"alpha": numpy.nan,
-                                "beta": numpy.nan}
+                    defaults = {"alpha": np.nan,
+                                "beta": np.nan}
             elif rt == libinference.rec_type.real_normal:
                 if rec_params[i] != "microcanonical":
                     defaults = {"m0": self.rec[i].fa.mean(),
@@ -438,17 +418,17 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
                                 "v0": self.rec[i].fa.std() ** 2,
                                 "nu0": 3}
                 else:
-                    defaults = {"m0": numpy.nan,
-                                "k0": numpy.nan,
-                                "v0": numpy.nan,
-                                "nu0": numpy.nan}
+                    defaults = {"m0": np.nan,
+                                "k0": np.nan,
+                                "v0": np.nan,
+                                "nu0": np.nan}
             elif rt == libinference.rec_type.discrete_geometric:
                 if rec_params[i] != "microcanonical":
                     defaults = {"alpha": 1,
                                 "beta": 1}
                 else:
-                    defaults = {"alpha": numpy.nan,
-                                "beta": numpy.nan}
+                    defaults = {"alpha": np.nan,
+                                "beta": np.nan}
             elif rt == libinference.rec_type.discrete_binomial:
                 if rec_params[i] != "microcanonical":
                     defaults = {"N": self.rec[i].fa.max(),
@@ -456,8 +436,8 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
                                 "beta": 1}
                 else:
                     defaults = {"N": self.rec[i].fa.max(),
-                                "alpha": numpy.nan,
-                                "beta": numpy.nan}
+                                "alpha": np.nan,
+                                "beta": np.nan}
 
             ks = list(defaults.keys())
             if rec_params[i] != "microcanonical":
@@ -552,7 +532,9 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
 
 
     def __getstate__(self):
-        state = dict(g=self.g,
+        state = EntropyState.__getstate__(self)
+        state = dict(state,
+                     g=self.g,
                      eweight=self.eweight if self.is_weighted else None,
                      vweight=self.vweight if self.is_weighted else None,
                      b=self.b,
@@ -598,7 +580,7 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
             eweight = self.mrs
             brec = self.brec
             bdrec = self.bdrec
-            # if self.g.get_vertex_filter()[0] is not None:
+            # if self.g.get_vertex_filter() is not None:
             #     bg = GraphView(bg, vfilt=numpy.ones(bg.num_vertices()))
 
         copy_coupled = False
@@ -633,7 +615,7 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
                     recs.append(bg.new_ep("double", eweight.fa > 0))
                     rec_types.append(rt)
                     rec_params.append("microcanonical")
-                elif numpy.isnan(rp.a).sum() == 0:
+                elif np.isnan(rp.a).sum() == 0:
                     continue
                 elif rt in [libinference.rec_type.discrete_geometric,
                             libinference.rec_type.discrete_binomial,
@@ -699,21 +681,21 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
         :math:`H=-\sum_r\frac{n_r}{N}\ln \frac{n_r}{N}`, where :math:`n_r` is
         the number of nodes in group r.
         """
-        w = numpy.array(self.wr.a, dtype="double")
+        w = np.array(self.wr.a, dtype="double")
         w = w[w>0]
         w /= w.sum()
-        return numpy.exp(-(w*log(w)).sum())
+        return np.exp(-(w*np.log(w)).sum())
 
     def get_bclabel(self, clabel=None):
         r"""Returns a :class:`~graph_tool.VertexPropertyMap` corresponding to constraint
         labels for the block graph."""
 
         bclabel = self.bg.new_vertex_property("int")
-        idx = self.vweight.a > 0
-        reverse_map(self.b.a[idx], bclabel)
+        idx = self.vweight.fa > 0
+        reverse_map(self.b.fa[idx], bclabel)
         if clabel is None:
             clabel = self.clabel
-        pmap(bclabel, clabel.a[idx])
+        pmap(bclabel, clabel.fa[idx])
         return bclabel
 
     def _set_bclabel(self, bstate):
@@ -795,12 +777,12 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
         return self.wr
 
     @copy_state_wrap
-    def entropy(self, adjacency=True, dl=True, partition_dl=True,
-                degree_dl=True, degree_dl_kind="distributed", edges_dl=True,
-                dense=False, multigraph=True, deg_entropy=True, recs=True,
-                recs_dl=True, beta_dl=1., Bfield=True, exact=True, **kwargs):
-        r"""Calculate the entropy (a.k.a. negative log-likelihood) associated
-        with the current block partition.
+    def _entropy(self, adjacency=True, dl=True, partition_dl=True,
+                 degree_dl=True, degree_dl_kind="distributed", edges_dl=True,
+                 dense=False, multigraph=True, deg_entropy=True, recs=True,
+                 recs_dl=True, beta_dl=1., Bfield=True, exact=True, **kwargs):
+        r"""Calculate the description length (a.k.a. negative joint
+        log-likelihood) associated with the current block partition.
 
         Parameters
         ----------
@@ -837,6 +819,9 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
             length will be included.
         beta_dl : ``double`` (optional, default: ``1.``)
             Prior inverse temperature.
+        Bfield : ``bool`` (optional, default: ``False``)
+            If True, the ``Bfield`` parameter passed to the construtor will be
+            taken into account.
         exact : ``bool`` (optional, default: ``True``)
             If ``True``, the exact expressions will be used. Otherwise,
             Stirling's factorial approximation will be used for some terms.
@@ -975,13 +960,21 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
                 P(\boldsymbol{k}|\boldsymbol{e},\boldsymbol{b}) = \prod_r\frac{\prod_k\eta_k^r!}{n_r!} \prod_r q(e_r, n_r)^{-1}
 
             with :math:`\eta_k^r` being the number of nodes with degree
-            :math:`k` in group :math:`r`, and :math:`q(n,m)` being the number of
+            :math:`k` in group :math:`r`, and :math:`q(m,n)` being the number of
             `partitions
             <https://en.wikipedia.org/wiki/Partition_(number_theory)>`_ of
-            integer :math:`n` into at most :math:`m` parts.
+            integer :math:`m` into at most :math:`n` parts. This is given by the
+            recurrence
+
+            .. math::
+
+                q(m, n) = q(m, n-1) + q(m-n, n),
+
+            with boundary conditions :math:`q(m,n) = q(m,m)` for :math:`n>m`,
+            :math:`q(m,0) = 0` for :math:`m>0`, and :math:`q(0,0) = 1`.
 
             This corresponds to a prior for the degree sequence conditioned on
-            the degree frequencies, which are themselves sampled from a uniform
+            the degree counts, which are themselves sampled from a uniform
             hyperprior. This option should be preferred in most cases.
 
         3. ``degree_dl_kind == "entropy"``
@@ -1017,7 +1010,7 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
 
         """
 
-        eargs = self._get_entropy_args(locals(), ignore=["self", "kwargs"])
+        eargs = self._get_entropy_args(locals())
 
         S = self._state.entropy(eargs, kwargs.pop("propagate", False))
 
@@ -1027,57 +1020,28 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
                              str(list(kwargs.keys())))
         return S
 
-    def _get_entropy_args(self, kwargs, ignore=None):
-        kwargs = dict(self._entropy_args, **kwargs)
-        if ignore is not None:
-            for a in ignore:
-                kwargs.pop(a, None)
-        args = DictState(kwargs)
-        deg_dl_kind = args.degree_dl_kind
-        del kwargs["degree_dl_kind"]
+    def _gen_eargs(self, args):
+        return libinference.entropy_args()
+
+    def _get_entropy_args(self, kwargs, consume=False):
+        if not consume:
+            kwargs = kwargs.copy()
+        deg_dl_kind = kwargs.get("degree_dl_kind",
+                                 self._entropy_args["degree_dl_kind"])
         if deg_dl_kind == "entropy":
             kind = libinference.deg_dl_kind.ent
         elif deg_dl_kind == "uniform":
             kind = libinference.deg_dl_kind.uniform
         elif deg_dl_kind == "distributed":
             kind = libinference.deg_dl_kind.dist
-        ea = libinference.entropy_args()
-        ea.exact = args.exact
-        ea.dense = args.dense
-        ea.multigraph = args.multigraph
-        ea.adjacency = args.adjacency
-        ea.deg_entropy = args.deg_entropy
-        ea.recs = args.recs
-        del kwargs["exact"]
-        del kwargs["dense"]
-        del kwargs["multigraph"]
-        del kwargs["adjacency"]
-        del kwargs["deg_entropy"]
-        del kwargs["recs"]
-        if args.dl:
-            ea.partition_dl = args.partition_dl
-            ea.degree_dl = args.degree_dl
-            ea.edges_dl = args.edges_dl
-            ea.recs_dl = args.recs_dl
-        else:
+        kwargs["degree_dl_kind"] = kind
+        dl = kwargs.get("dl", self._entropy_args["dl"])
+        ea = super()._get_entropy_args(kwargs, consume)
+        if not dl:
             ea.partition_dl = False
             ea.degree_dl = False
             ea.edges_dl = False
             ea.recs_dl = False
-        ea.degree_dl_kind = kind
-        ea.beta_dl = args.beta_dl
-        ea.Bfield = args.Bfield
-        del kwargs["dl"]
-        del kwargs["partition_dl"]
-        del kwargs["degree_dl"]
-        del kwargs["edges_dl"]
-        del kwargs["recs_dl"]
-        del kwargs["beta_dl"]
-        del kwargs["Bfield"]
-        kwargs.pop("callback", None)
-        if len(kwargs) > 0:
-            raise ValueError("unrecognized entropy arguments: " +
-                             str(list(kwargs.keys())))
         return ea
 
     def get_matrix(self):
@@ -1138,8 +1102,8 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
         if not isinstance(v, collections.abc.Iterable):
             self._state.move_vertex(int(v), s)
         else:
-            self._state.move_vertices(numpy.asarray(v, dtype="uint64"),
-                                      numpy.asarray(s, dtype="uint64"))
+            self._state.move_vertices(np.asarray(v, dtype="uint64"),
+                                      np.asarray(s, dtype="uint64"))
 
     def remove_vertex(self, v):
         r"""Remove vertex ``v`` from its current group.
@@ -1153,9 +1117,9 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
            twice.
         """
         if isinstance(v, collections.abc.Iterable):
-            if not isinstance(v, numpy.ndarray):
+            if not isinstance(v, np.ndarray):
                 v = list(v)
-            self._state.remove_vertices(numpy.asarray(v, dtype="uint64"))
+            self._state.remove_vertices(np.asarray(v, dtype="uint64"))
         else:
             self._state.remove_vertex(int(v))
 
@@ -1170,12 +1134,12 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
            added twice to the same group.
         """
         if isinstance(v, collections.abc.Iterable):
-            if not isinstance(v, numpy.ndarray):
+            if not isinstance(v, np.ndarray):
                 v = list(v)
-            if not isinstance(r, numpy.ndarray):
+            if not isinstance(r, np.ndarray):
                 r = list(r)
-            self._state.add_vertices(numpy.asarray(v, dtype="uint64"),
-                                     numpy.asarray(r, dtype="uint64"))
+            self._state.add_vertices(np.asarray(v, dtype="uint64"),
+                                     np.asarray(r, dtype="uint64"))
         else:
             self._state.add_vertex(int(v), r)
 
@@ -1404,7 +1368,7 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
            ...     ret = state.mcmc_sweep(niter=10)
            ...     pe = state.collect_edge_marginals(pe)
            >>> gt.bethe_entropy(g, pe)[0]
-           -31.287603...
+           7.106015...
 
         """
 
@@ -1462,7 +1426,7 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
            ...     ret = state.mcmc_sweep(niter=10)
            ...     pv = state.collect_vertex_marginals(pv)
            >>> gt.mf_entropy(g, pv)
-           33.404545...
+           22.533702...
            >>> gt.graph_draw(g, pos=g.vp["pos"], vertex_shape="pie",
            ...               vertex_pie_fractions=pv, output="polbooks_blocks_soft_B4.svg")
            <...>
@@ -1523,7 +1487,7 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
            ...     ret = state.mcmc_sweep(niter=10)
            ...     ph = state.collect_partition_histogram(ph)
            >>> gt.microstate_entropy(ph)
-           127.398615...
+           132.299325...
 
         """
 
@@ -1613,12 +1577,12 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
                 if not self.g.is_directed():
                     p = 2 * self.g.num_edges() / ((B + 1) * B)
                 idx = probs.nonzero()
-                probs[idx] = numpy.random.gamma(probs[idx] + 1, p/(p + 1))
+                probs[idx] = np.random.gamma(probs[idx] + 1, p/(p + 1))
                 for r in rs:
                     idx = self.b.fa == r
-                    out_degs[idx] = numpy.random.dirichlet(out_degs[idx] + 1)
+                    out_degs[idx] = np.random.dirichlet(out_degs[idx] + 1)
                     if in_degs is not None:
-                        in_degs[idx] = numpy.random.dirichlet(in_degs[idx] + 1)
+                        in_degs[idx] = np.random.dirichlet(in_degs[idx] + 1)
 
             g = generate_sbm(b=self.b.fa, probs=probs,
                              in_degs=in_degs, out_degs=out_degs,
