@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -34,7 +34,7 @@ from . uncertain_blockmodel import UncertainBaseState
 
 import numpy.random
 
-class LatentLayerBaseState(object):
+class LatentLayerBaseState(EntropyState):
     r"""Base state for uncertain latent layer network inference."""
 
     def get_ec(self, ew=None):
@@ -89,18 +89,18 @@ class LatentLayerBaseState(object):
                 gs.append(g)
 
         for l, g in enumerate(gs):
-            if "eprob" not in g.ep:
-                g.ep.eprob = g.new_ep("double")
-
             u = self.us[l] if l < len(self.us) else self.g
             if l == 0:
                 es = edge_endpoint_property(u, u.vertex_index, "source")
                 et = edge_endpoint_property(u, u.vertex_index, "target")
                 u = GraphView(u, efilt=es.fa != et.fa)
-            libinference.collect_marginal(g._Graph__graph,
-                                          u._Graph__graph,
-                                          _prop("e", g, g.ep.count))
+
+            g.set_fast_edge_lookup(True)
+            graph_merge(g, u, in_place=True, simple=True,
+                        props={"sum": [(g.ep.count, u.new_ep("int", val=1))]})
             g.gp.count += 1
+            if "eprob" not in g.ep:
+                g.ep.eprob = g.new_ep("double")
             g.ep.eprob.fa = g.ep.count.fa
             g.ep.eprob.fa /= g.gp.count
         return gs
@@ -155,16 +155,13 @@ class LatentLayerBaseState(object):
                                                 _prop("e", g, g.ep.wcount))
         return gs
 
-    def _get_entropy_args(self, entropy_args):
+    def _gen_eargs(self, args):
         if isinstance(self.bstates[0], NestedBlockState):
             bstate = self.bstates[0].levels[0]
         else:
             bstate = self.bstates[0]
-        ea = bstate._get_entropy_args(entropy_args, ignore=["latent_edges", "density"])
-        uea = libinference.uentropy_args(ea)
-        uea.latent_edges = entropy_args.get("latent_edges", True)
-        uea.density = entropy_args.get("density", True)
-        return uea
+        ea = bstate._get_entropy_args(args, consume=True)
+        return libinference.uentropy_args(ea)
 
     def _mcmc_sweep(self, mcmc_state):
         return libinference.mcmc_latent_layers_sweep(mcmc_state,
@@ -216,6 +213,7 @@ class LatentLayerBaseState(object):
         return self.mcmc_sweep(multiflip=True, **kwargs)
 
 
+@entropy_state_signature
 class LatentClosureBlockState(LatentLayerBaseState):
     r"""Inference state of the stochastic block model with latent triadic closure
     edges.
@@ -248,16 +246,24 @@ class LatentClosureBlockState(LatentLayerBaseState):
         List of edge property maps of ``g``, each containing a list of integers
         with the ego graph memberships of every edge, for every triadic
         generation.
+    entropy_args: ``dict`` (optional, default: ``{}``)
+        Override default arguments for
+        :meth:`~LatentClosureBlockState.entropy()` method and releated
+        operations.
 
     References
     ----------
     .. [peixoto-disentangling-2022] Tiago P. Peixoto, "Disentangling homophily,
        community structure and triadic closure in networks", Phys. Rev. X 12,
        011004 (2022), :doi:`10.1103/PhysRevX.12.011004`, :arxiv:`2101.02510`
+
     """
 
     def __init__(self, g, L=1, b=None, aE=numpy.nan, nested=True,
-                 state_args={}, g_orig=None, ew=None, ex=None, **kwargs):
+                 state_args={}, g_orig=None, ew=None, ex=None, entropy_args={},
+                 **kwargs):
+        EntropyState.__init__(self, entropy_args=entropy_args)
+
         self.g = g
         self.us = []
         self.ew = []
@@ -296,6 +302,8 @@ class LatentClosureBlockState(LatentLayerBaseState):
         else:
             self.pstate = self.bstate
 
+        self._entropy_args.update(self.pstate._entropy_args)
+
         self.aE = aE
         if numpy.isnan(aE):
             self.E_prior = False
@@ -359,7 +367,8 @@ class LatentClosureBlockState(LatentLayerBaseState):
         pstate = self.pstate._state
 
     def __getstate__(self):
-        return dict(g=self.g, L=self.L-1,
+        state = EntropyState.__getstate__(self)
+        return dict(state, g=self.g, L=self.L-1,
                     b=self.bstate.get_bs() if self.nested else self.bstate.b.copy(),
                     aE=self.aE, nested=self.nested,
                     state_args=self.state_args, g_orig=self.g_orig,
@@ -380,9 +389,10 @@ class LatentClosureBlockState(LatentLayerBaseState):
             (", ".join([str(w.fa.sum()) for w in self.ew[1:]]), repr(self.bstate), id(self))
 
     @copy_state_wrap
-    def entropy(self, latent_edges=True, density=True, **kwargs):
+    def _entropy(self, latent_edges=True, density=False, aE=1., sbm=True, **kwargs):
         """Return the entropy, i.e. negative log-likelihood."""
-        S = self._state.entropy(latent_edges, density)
+        eargs = self._get_entropy_args(locals())
+        S = self._state.entropy(eargs)
         S += self.bstates[0].entropy(**kwargs)
         for s in self._cstates[1:]:
             S += s.entropy()
