@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2025 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -29,6 +29,7 @@ from . base_states import *
 from .. dl_import import dl_import
 dl_import("from . import libgraph_tool_inference as libinference")
 
+@entropy_state_signature
 class NormCutState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
                    GibbsMCMCState, DrawBlockState):
     r"""Obtain the partition of a network according to the normalized cut.
@@ -54,7 +55,7 @@ class NormCutState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
     """
 
     def __init__(self, g, b=None):
-
+        EntropyState.__init__(self)
         self.g = GraphView(g, directed=False)
         if b is None:
             self.b = self.g.new_vp("int32_t")
@@ -70,8 +71,6 @@ class NormCutState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
         self._abg = self.bg._get_any()
         self._state = libinference.make_norm_cut_state(self)
 
-        self._entropy_args = {}
-
     def __copy__(self):
         return self.copy()
 
@@ -96,6 +95,9 @@ class NormCutState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
         return "<NormCutState object with %d blocks, for graph %s, at 0x%x>" % \
             (self.get_B(), str(self.g), id(self))
 
+    def _gen_eargs(self, args):
+        return libinference.modularity_entropy_args()
+
     def get_B(self):
         r"Returns the total number of blocks."
         return len(np.unique(self.b.fa))
@@ -111,15 +113,11 @@ class NormCutState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
         return np.exp(-(w*log(w)).sum())
 
     @copy_state_wrap
-    def entropy(self, **kwargs):
+    def _entropy(self):
         r"""Return the normalized cut. See :meth:`~NormCutState.norm_cut`."""
 
         eargs = self._get_entropy_args(locals(), ignore=["self", "kwargs"])
 
-        if len(kwargs) > 0:
-            raise ValueError("unrecognized keyword arguments: " +
-                             str(list(kwargs.keys())))
-
         return self._state.entropy(eargs)
 
     def _get_entropy_args(self, kwargs, ignore=None):
